@@ -1,12 +1,15 @@
+"""
+Generic DB rows writer
+"""
+
 import sqlalchemy as sa
+from pvsite_datamodel.sqlmodels import Base
+from pvsite_datamodel.write.utils import WrittenRow
 from sqlalchemy import orm as sa_orm
 from sqlalchemy.dialects import postgresql as sa_psql
 
-from pvsite_datamodel import sqlmodels
-from pvsite_datamodel.write.utils import WrittenRow
 
-
-def upsert(session: sa_orm.Session, table: sqlmodels.Base, rows: list[dict]) -> list[WrittenRow]:
+def upsert(session: sa_orm.Session, table: Base, rows: list[dict]) -> list[WrittenRow]:
     """
     Upsert rows into table
 
@@ -37,4 +40,4 @@ def upsert(session: sa_orm.Session, table: sqlmodels.Base, rows: list[dict]) ->
     session.execute(stmt, rows)
     session.commit()
 
-    return [WrittenRow(table=table, pk_value=row[primary_key_names[0]]) for row in rows]
\ No newline at end of file
+    return [WrittenRow(table=table, pk_value=row[primary_key_names[0]]) for row in rows]
