@@ -1,7 +1,11 @@
+"""
+Cross-package functions
+"""
+
 import datetime as dt
 import typing
 
-from pvsite_datamodel import sqlmodels
+from pvsite_datamodel.sqlmodels import Base
 
 
 class WrittenRow(typing.NamedTuple):
@@ -9,8 +13,8 @@ class WrittenRow(typing.NamedTuple):
     Defines a write to the Database
     """
 
-    table: sqlmodels.Base
+    table: Base
     pk_value: str
 
 
-FORECAST_TIMESPAN = dt.timedelta(minutes=5)
\ No newline at end of file
+FORECAST_TIMESPAN = dt.timedelta(minutes=5)
